@@ -316,65 +316,6 @@ static int set_password(struct parsed_mount_info *parsed_info, const char *src)
 	return 0;
 }
 
-/*
- * Parse a username string into parsed_mount_info fields. The format is:
- *
- * DOMAIN\username%password
- *
- * ...obviously the only required component is "username". The source string
- * is modified in the process, but it should remain unchanged at the end.
- *
- * NOTE: the above syntax does not allow for usernames that have slashes in
- * them, as some krb5 usernames do. Support for the above syntax will be
- * removed in a later version of cifs-utils. Users should use separate options
- * instead of overloading this info into the username.
- */
-static int parse_username(char *rawuser, struct parsed_mount_info *parsed_info)
-{
-	char *user, *password, slash;
-	int rc = 0;
-	bool warn = false;
-
-	/* everything after first % sign is a password */
-	password = strchr(rawuser, '%');
-	if (password) {
-		warn = true;
-		rc = set_password(parsed_info, password + 1);
-		if (rc)
-			return rc;
-		*password = '\0';
-	}
-
-	/* everything after first '/' or '\' is a username */
-	user = strchr(rawuser, '/');
-	if (!user)
-		user = strchr(rawuser, '\\');
-
-	/* everything before that slash is a domain */
-	if (user) {
-		warn = true;
-		slash = *user;
-		*user = '\0';
-		strlcpy(parsed_info->domain, rawuser,
-			sizeof(parsed_info->domain));
-		*(user++) = slash;
-	} else {
-		user = rawuser;
-	}
-
-	strlcpy(parsed_info->username, user, sizeof(parsed_info->username));
-	parsed_info->got_user = 1;
-	if (password)
-		*password = '%';
-
-	if (warn)
-		fprintf(stderr, "WARNING: The DOMAIN/username%%password syntax "
-				"for usernames is deprecated and will be "
-				"removed in version 5.9 of cifs-utils.\n");
-
-	return 0;
-}
-
 #ifdef HAVE_LIBCAP_NG
 static int
 drop_capabilities(int parent)
@@ -590,8 +531,7 @@ parsing_err:
 }
 
 static int open_cred_file(char *file_name,
-			struct parsed_mount_info *parsed_info,
-			char **saved_username)
+			struct parsed_mount_info *parsed_info)
 {
 	char *line_buf = NULL;
 	char *temp_val = NULL;
@@ -640,11 +580,9 @@ static int open_cred_file(char *file_name,
 		/* parse next token */
 		switch (parse_cred_line(line_buf + i, &temp_val)) {
 		case CRED_USER:
-			*saved_username = strdup(temp_val);
-			if (!*saved_username) {
-				i = EX_SYSERR;
-				goto return_i;
-			}
+			strlcpy(parsed_info->username, temp_val,
+				sizeof(parsed_info->username));
+			parsed_info->got_user = 1;
 			break;
 		case CRED_PASS:
 			i = set_password(parsed_info, temp_val);
@@ -834,8 +772,6 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 	char *ep;
 	struct passwd *pw;
 	struct group *gr;
-	char *saved_username = NULL;
-	bool krb5_auth = false;
 	/*
 	 * max 32-bit uint in decimal is 4294967295 which is 10 chars wide
 	 * +1 for NULL, and +1 for good measure
@@ -895,19 +831,9 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 					return EX_USAGE;
 				}
 			} else {
-				/* domain/username%password  + NULL term. */
-				const size_t max = MAX_DOMAIN_SIZE +
-						   MAX_USERNAME_SIZE +
-						   MOUNT_PASSWD_SIZE + 2 + 1;
-				if (strnlen(value, max) >= max) {
-					fprintf(stderr, "username too long\n");
-					return EX_USAGE;
-				}
-				saved_username = strdup(value);
-				if (!saved_username) {
-					fprintf(stderr, "Unable to allocate memory!\n");
-					return EX_SYSERR;
-				}
+				strlcpy(parsed_info->username, value,
+					sizeof(parsed_info->username));
+				parsed_info->got_user = 1;
 				goto nocopy;
 			}
 
@@ -928,12 +854,9 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 
 		case OPT_SEC:
 			if (value) {
-				if (!strncmp(value, "none", 4)) {
+				if (!strncmp(value, "none", 4) ||
+				    !strncmp(value, "krb5", 4))
 					parsed_info->got_password = 1;
-				} else if (!strncmp(value, "krb5", 4)) {
-					parsed_info->got_password = 1;
-					krb5_auth = true;
-				}
 			}
 			break;
 
@@ -989,7 +912,7 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 					"invalid credential file name specified\n");
 				return EX_USAGE;
 			}
-			rc = open_cred_file(value, parsed_info, &saved_username);
+			rc = open_cred_file(value, parsed_info);
 			if (rc) {
 				fprintf(stderr,
 					"error %d (%s) opening credential file %s\n",
@@ -1003,58 +926,56 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 				goto nocopy;
 
 			got_uid = 1;
+			pw = getpwnam(value);
+			if (pw) {
+				uid = pw->pw_uid;
+				goto nocopy;
+			}
+
 			errno = 0;
 			uid = strtoul(value, &ep, 10);
 			if (errno == 0 && *ep == '\0')
 				goto nocopy;
 
-			pw = getpwnam(value);
-			if (pw == NULL) {
-				fprintf(stderr, "bad user name \"%s\"\n", value);
-				return EX_USAGE;
-			}
-
-			uid = pw->pw_uid;
-			goto nocopy;
-
+			fprintf(stderr, "bad option uid=\"%s\"\n", value);
+			return EX_USAGE;
 		case OPT_CRUID:
 			if (!value || !*value)
 				goto nocopy;
 
 			got_cruid = 1;
+			pw = getpwnam(value);
+			if (pw) {
+				cruid = pw->pw_uid;
+				goto nocopy;
+			}
+
 			errno = 0;
 			cruid = strtoul(value, &ep, 10);
 			if (errno == 0 && *ep == '\0')
 				goto nocopy;
 
-			pw = getpwnam(value);
-			if (pw == NULL) {
-				fprintf(stderr, "bad user name \"%s\"\n", value);
-				return EX_USAGE;
-			}
-			cruid = pw->pw_uid;
-			goto nocopy;
-
+			fprintf(stderr, "bad option: cruid=\"%s\"\n", value);
+			return EX_USAGE;
 		case OPT_GID:
 			if (!value || !*value)
 				goto nocopy;
 
 			got_gid = 1;
+			gr = getgrnam(value);
+			if (gr) {
+				gid = gr->gr_gid;
+				goto nocopy;
+			}
+
 			errno = 0;
 			gid = strtoul(value, &ep, 10);
 			if (errno == 0 && *ep == '\0')
 				goto nocopy;
 
-			gr = getgrnam(value);
-			if (gr == NULL) {
-				fprintf(stderr, "bad group name \"%s\"\n", value);
-				return EX_USAGE;
-			}
-
-			gid = gr->gr_gid;
-			goto nocopy;
-
-		/* fmask fall through to file_mode */
+			fprintf(stderr, "bad option: gid=\"%s\"\n", value);
+			return EX_USAGE;
+		/* fmask falls through to file_mode */
 		case OPT_FMASK:
 			fprintf(stderr,
 				"WARNING: CIFS mount option 'fmask' is\
@@ -1093,23 +1014,15 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 					"WARNING: '%s' not expressed in octal.\n",
 					data);
 			break;
-
-		/* the following mount options should be
-		   stripped out from what is passed into the kernel
-		   since these options are best passed as the
-		   mount flags rather than redundantly to the kernel
-		   and could generate spurious warnings depending on the
-		   level of the corresponding cifs vfs kernel code */
 		case OPT_NO_SUID:
 			*filesys_flags |= MS_NOSUID;
-			break;
+			goto nocopy;
 		case OPT_SUID:
 			*filesys_flags &= ~MS_NOSUID;
-			break;
+			goto nocopy;
 		case OPT_NO_DEV:
 			*filesys_flags |= MS_NODEV;
-			break;
-		/* nolock || nobrl */
+			goto nocopy;
 		case OPT_NO_LOCK:
 			*filesys_flags &= ~MS_MANDLOCK;
 			break;
@@ -1121,17 +1034,17 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 			goto nocopy;
 		case OPT_DEV:
 			*filesys_flags &= ~MS_NODEV;
-			break;
+			goto nocopy;
 		case OPT_NO_EXEC:
 			*filesys_flags |= MS_NOEXEC;
-			break;
+			goto nocopy;
 		case OPT_EXEC:
 			*filesys_flags &= ~MS_NOEXEC;
-			break;
+			goto nocopy;
 		case OPT_GUEST:
 			parsed_info->got_user = 1;
 			parsed_info->got_password = 1;
-			break;
+			goto nocopy;
 		case OPT_RO:
 			*filesys_flags |= MS_RDONLY;
 			goto nocopy;
@@ -1140,7 +1053,7 @@ parse_options(const char *data, struct parsed_mount_info *parsed_info)
 			goto nocopy;
 		case OPT_REMOUNT:
 			*filesys_flags |= MS_REMOUNT;
-			break;
+			goto nocopy;
 		case OPT_IGNORE:
 			goto nocopy;
 		case OPT_BKUPUID:
@@ -1211,21 +1124,6 @@ nocopy:
 		data = next_keyword;
 	}
 
-	if (saved_username) {
-		if (krb5_auth) {
-			strlcpy(parsed_info->username, saved_username,
-				sizeof(parsed_info->username));
-			parsed_info->got_user = 1;
-		} else {
-			rc = parse_username(saved_username, parsed_info);
-			free(saved_username);
-			if (rc) {
-				fprintf(stderr, "Unable to parse username!\n");
-				return rc;
-			}
-		}
-	}
-
 
 	/* special-case the uid and gid */
 	if (got_uid) {
@@ -1247,7 +1145,7 @@ nocopy:
 	if (got_cruid) {
 		word_len = snprintf(txtbuf, sizeof(txtbuf), "%u", cruid);
 
-		/* comma + "cruid=" + terminating NULL == 6 */
+		/* comma + "cruid=" + terminating NULL == 8 */
 		if (out_len + word_len + 8 > MAX_OPTIONS_LEN) {
 			fprintf(stderr, "Options string too long\n");
 			return EX_USAGE;
@@ -1334,33 +1232,19 @@ static int parse_unc(const char *unc_name, struct parsed_mount_info *parsed_info
 		return EX_USAGE;
 	}
 
-	/* Set up "host" and "share" pointers based on UNC format. */
 	if (strncmp(unc_name, "//", 2) && strncmp(unc_name, "\\\\", 2)) {
-		/*
-		 * check for nfs syntax (server:/share/prepath)
-		 *
-		 * FIXME: IPv6 addresses?
-		 */
-		host = unc_name;
-		share = strchr(host, ':');
-		if (!share) {
-			fprintf(stderr, "mount.cifs: bad UNC (%s)\n", unc_name);
-			return EX_USAGE;
-		}
-		hostlen = share - host;
-		share++;
-		if (*share == '/')
-			++share;
-	} else {
-		host = unc_name + 2;
-		hostlen = strcspn(host, "/\\");
-		if (!hostlen) {
-			fprintf(stderr, "mount.cifs: bad UNC (%s)\n", unc_name);
-			return EX_USAGE;
-		}
-		share = host + hostlen + 1;
+		fprintf(stderr, "mount.cifs: bad UNC (%s)\n", unc_name);
+		return EX_USAGE;
 	}
 
+	host = unc_name + 2;
+	hostlen = strcspn(host, "/\\");
+	if (!hostlen) {
+		fprintf(stderr, "mount.cifs: bad UNC (%s)\n", unc_name);
+		return EX_USAGE;
+	}
+	share = host + hostlen + 1;
+
 	if (hostlen + 1 > sizeof(parsed_info->host)) {
 		fprintf(stderr, "mount.cifs: host portion of UNC too long\n");
 		return EX_USAGE;
@@ -2067,7 +1951,7 @@ int main(int argc, char **argv)
 		}
 	}
 
-	if (argc < 3 || argv[optind] == NULL || argv[optind + 1] == NULL) {
+	if (argc < optind + 2) {
 		rc = mount_usage(stderr);
 		goto mount_exit;
 	}
